@@ -40,5 +40,5 @@ urlpatterns = [
     path("<int:incident_pk>/acks/<int:pk>/", ack_detail, name="incident-ack"),
     path("<int:incident_pk>/tags/", tag_list, name="incident-tags"),
     path("<int:incident_pk>/tags/<str:tag>/", tag_detail, name="incident-tag"),
-    path("<int:incident_pk>/ticket/", ticket_plugin_detail, name="incident-ticket-plugin"),
+    path("<int:incident_pk>/automatic-ticket/", ticket_plugin_detail, name="incident-ticket-plugin"),
 ] + router.urls
