@@ -657,7 +657,7 @@ class IncidentViewSetTestCase(APITestCase):
     def test_can_get_existing_ticket_url_of_incident(self):
         ticket_url = "www.example.com"
         pk = StatefulIncidentFactory(ticket_url=ticket_url).pk
-        response = self.client.put(path=f"/api/v2/incidents/{pk}/ticket/")
+        response = self.client.put(path=f"/api/v2/incidents/{pk}/automatic-ticket/")
         self.assertEqual(response.status_code, status.HTTP_200_OK)
         self.assertEqual(response.data["ticket_url"], ticket_url)
 
